<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar" sourcelanguage="en">
  <context>
    <name>CmdRaytracingExportProject</name>
    <message>
      <location filename="../../Command.cpp" line="522"/>
      <source>File</source>
      <translation>ملف</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="523"/>
      <source>&amp;Export project...</source>
      <translation>&amp; تصدير المشروع...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="524"/>
      <source>Export a Raytracing project to a file</source>
      <translation>تصدير مشروع Raytracing إلى ملف</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewLuxProject</name>
    <message>
      <location filename="../../Command.cpp" line="756"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="757"/>
      <source>New Luxrender project</source>
      <translation>مشروع Luxrender جديد</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="758"/>
      <source>Insert new Luxrender project into the document</source>
      <translation>إدراج مشروع Luxrender جديد في المستند</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="810"/>
      <source>No template</source>
      <translation>لا يوجد قالب</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="811"/>
      <source>No template available</source>
      <translation>لا يوجد قالب متاح</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPartSegment</name>
    <message>
      <location filename="../../Command.cpp" line="438"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="439"/>
      <source>Insert part</source>
      <translation>إدراج جزء</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="440"/>
      <source>Insert a new part object into a Raytracing project</source>
      <translation>إدراج جزء كائن جديد في مشروع Raytracing</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPovrayProject</name>
    <message>
      <location filename="../../Command.cpp" line="321"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="322"/>
      <source>New POV-Ray project</source>
      <translation>مشروع POV-Ray جديد</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="323"/>
      <source>Insert new POV-Ray project into the document</source>
      <translation>إدراج مشروع POV-Ray جديد في المستند</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="375"/>
      <source>No template</source>
      <translation>لا يوجد قالب</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="376"/>
      <source>No template available</source>
      <translation>لا يوجد قالب متاح</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingRender</name>
    <message>
      <location filename="../../Command.cpp" line="589"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="590"/>
      <source>&amp;Render</source>
      <translation>&amp; تقديم</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="591"/>
      <source>Renders the current raytracing project with an external renderer</source>
      <translation>يعرض المشروع raytracing الحالي مع عارض خارجي</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingResetCamera</name>
    <message>
      <location filename="../../Command.cpp" line="869"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="870"/>
      <source>&amp;Reset Camera</source>
      <translation>&amp;إعادة تعيين الكاميرا</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="871"/>
      <source>Sets the camera of the selected Raytracing project to match the current view</source>
      <translation>تعيين الكاميرا الخاصة بالمشروع Raytracing المحدد لتتناسب مع طريقة العرض الحالية</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteCamera</name>
    <message>
      <location filename="../../Command.cpp" line="82"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <source>Export camera to POV-Ray...</source>
      <translation>تصدير الكاميرا إلى POV-Ray...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <source>Export the camera position of the active 3D view in POV-Ray format to a file</source>
      <translation>تصدير موضع الكاميرا طريقة العرض 3D النشطة في تنسيق POV-Ray إلى ملف</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWritePart</name>
    <message>
      <location filename="../../Command.cpp" line="175"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="176"/>
      <source>Export part to POV-Ray...</source>
      <translation>تصدير جزء POV-Ray...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="177"/>
      <source>Write the selected Part (object) as a POV-Ray file</source>
      <translation>كتابة الجزء المحدد (عنصر) كملف POV-Ray</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteView</name>
    <message>
      <location filename="../../Command.cpp" line="98"/>
      <location filename="../../Command.cpp" line="237"/>
      <location filename="../../Command.cpp" line="337"/>
      <location filename="../../Command.cpp" line="772"/>
      <source>No perspective camera</source>
      <translation>لا كاميرا منظور</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="99"/>
      <location filename="../../Command.cpp" line="238"/>
      <location filename="../../Command.cpp" line="338"/>
      <source>The current view camera is not perspective and thus resulting in a POV-Ray image that may look different than what was expected.
Do you want to continue?</source>
      <translation type="unfinished">The current view camera is not perspective and thus resulting in a POV-Ray image that may look different than what was expected.
Do you want to continue?</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Export view to POV-Ray...</source>
      <translation>تصدير طريقة العرض إلى POV-Ray...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Write the active 3D view with camera and all its content to a POV-Ray file</source>
      <translation>اكتب العرض ثلاثي الأبعاد النشط مع الكاميرا وجميع محتوياتها إلى ملف POV-Ray</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="352"/>
      <location filename="../../Command.cpp" line="787"/>
      <source>No template</source>
      <translation>لا يوجد قالب</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="353"/>
      <location filename="../../Command.cpp" line="788"/>
      <source>Cannot create a project because there is no template installed.</source>
      <translation>لا يمكن عمل مشروع لأنه لم يتم تحميل أي قالب.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="773"/>
      <source>The current view camera is not perspective and thus resulting in a luxrender image that may look different than what was expected.
Do you want to continue?</source>
      <translation type="unfinished">The current view camera is not perspective and thus resulting in a luxrender image that may look different than what was expected.
Do you want to continue?</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="186"/>
      <location filename="../../Command.cpp" line="248"/>
      <location filename="../../Command.cpp" line="546"/>
      <source>POV-Ray</source>
      <translation>POV-Ray</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="136"/>
      <location filename="../../Command.cpp" line="187"/>
      <location filename="../../Command.cpp" line="249"/>
      <location filename="../../Command.cpp" line="551"/>
      <location filename="../../Command.cpp" line="665"/>
      <source>All Files</source>
      <translation>كل الملفات</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="137"/>
      <location filename="../../Command.cpp" line="188"/>
      <location filename="../../Command.cpp" line="251"/>
      <location filename="../../Command.cpp" line="553"/>
      <source>Export page</source>
      <translation>تصدير الصفحة</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="450"/>
      <location filename="../../Command.cpp" line="537"/>
      <location filename="../../Command.cpp" line="605"/>
      <location filename="../../Command.cpp" line="883"/>
      <source>Wrong selection</source>
      <translation>إختيار خاطئ</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="451"/>
      <source>Select a Part object.</source>
      <translation>قم بتحديد عنصر قطعة.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="461"/>
      <location filename="../../Command.cpp" line="473"/>
      <source>No Raytracing project to insert</source>
      <translation>لا يوجد مشروع Raytracing لإدراجه</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="462"/>
      <source>Create a Raytracing project to insert a view.</source>
      <translation>إنشاء مشروع Raytracing لإدراج طريقة العرض.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="474"/>
      <source>Select a Raytracing project to insert the view.</source>
      <translation>حدد مشروع Raytracing لإدراجه في طريقة العرض.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="538"/>
      <location filename="../../Command.cpp" line="606"/>
      <location filename="../../Command.cpp" line="884"/>
      <source>Select one Raytracing project object.</source>
      <translation>حدد كائن مشروع Raytracing واحد.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="542"/>
      <source>Luxrender</source>
      <translation>Luxrender</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="621"/>
      <location filename="../../Command.cpp" line="627"/>
      <source>POV-Ray not found</source>
      <translation>لم يتم العثور على POV-Ray</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="622"/>
      <source>Please set the path to the POV-Ray executable in the preferences.</source>
      <translation>الرجاء تعيين المسار إلى الملف التنفيذي POV-Ray في التفضيلات.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="628"/>
      <source>Please correct the path to the POV-Ray executable in the preferences.</source>
      <translation>الرجاء تصحيح المسار إلى الملف التنفيذي POV-Ray في التفضيلات.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="635"/>
      <location filename="../../Command.cpp" line="641"/>
      <source>Luxrender not found</source>
      <translation>لم يتم العثور على Luxrender</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="636"/>
      <source>Please set the path to the luxrender or luxconsole executable in the preferences.</source>
      <translation>الرجاء تعيين المسار إلى luxrender أو luxconsole القابل للتنفيذ في التفضيلات.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="642"/>
      <source>Please correct the path to the luxrender or luxconsole executable in the preferences.</source>
      <translation>الرجاء تصحيح المسار إلى luxrender أو luxconsole القابل للتنفيذ في التفضيلات.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="654"/>
      <source>POV-Ray file missing</source>
      <translation>ملف POV-Ray مفقود</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="655"/>
      <source>The POV-Ray project file doesn't exist.</source>
      <translation>لا يوجد ملف المشروع POV-Ray.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="661"/>
      <location filename="../../Command.cpp" line="663"/>
      <location filename="../../Command.cpp" line="666"/>
      <source>Rendered image</source>
      <translation>الصورة المعروضة</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="723"/>
      <source>Lux project file missing</source>
      <translation>ملف مشروع لوكس مفقود</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="724"/>
      <source>The Lux project file doesn't exist.</source>
      <translation>لا يوجد ملف المشروع لوكس.</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::DlgSettingsRay</name>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="14"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="26"/>
      <source>Mesh export settings</source>
      <translation>إعدادات تصدير شبكة</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="52"/>
      <source>Max mesh deviation:</source>
      <translation>أقصى انحراف في الشبكة:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="80"/>
      <source>Do not calculate vertex normals</source>
      <translation>لا تحسب الأوضاع الطبيعية لقمة الرأس</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="93"/>
      <source>Write u,v coordinates</source>
      <translation>اكتب الإحداثيات u,v</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="109"/>
      <source>Render</source>
      <translation>تقديم</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="127"/>
      <source>POV-Ray executable:</source>
      <translation>POV-Ray الملف القابل للتنفيذ:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="134"/>
      <source>POV-Ray output parameters:</source>
      <translation>معلمات الإخراج POV-Ray:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="143"/>
      <source>The POV-Ray parameters to be passed to the render.</source>
      <translation>لمعلمات POV-Ray لتمريرها إلى التجسيد.</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="146"/>
      <source>+P +A</source>
      <translation>+P +A</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="159"/>
      <source>+W: </source>
      <translation>+W: </translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="166"/>
      <source>The width of the rendered image</source>
      <translation>عرض الصورة المقدمة</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="185"/>
      <source> +H : </source>
      <translation> +H : </translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="192"/>
      <source>The height of the rendered image</source>
      <translation>ارتفاع الصورة المقدمة</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="213"/>
      <source>Luxrender executable:</source>
      <translation>Luxrender الملف القابل للتنفيذ:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="220"/>
      <source>The path to the luxrender (or luxconsole) executable</source>
      <translation>مسار luxrender (أو luxconsole) القابل للتنفيذ</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="238"/>
      <source>Directories</source>
      <translation>المسارات</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="258"/>
      <source>Part file name:</source>
      <translation>اسم جزء الملف:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="265"/>
      <source>Camera file name:</source>
      <translation>اسم ملف الكاميرا:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="275"/>
      <location filename="../../DlgSettingsRay.ui" line="298"/>
      <location filename="../../DlgSettingsRay.ui" line="314"/>
      <source>Used by utility tools</source>
      <translation>المستخدمة من قبل أدوات الأداة المساعدة</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="291"/>
      <source>Default Project dir:</source>
      <translation>دليل المشروع الافتراضي:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="301"/>
      <source>TempCamera.inc</source>
      <translation>TempCamera.inc</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="317"/>
      <source>TempPart.inc</source>
      <translation>TempPart.inc</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::DlgSettingsRayImp</name>
    <message>
      <location filename="../../DlgSettingsRayImp.cpp" line="47"/>
      <source>The path to the POV-Ray executable, if you want to render from %1</source>
      <translation type="unfinished">The path to the POV-Ray executable, if you want to render from %1</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::ViewProviderLux</name>
    <message>
      <location filename="../../ViewProvider.cpp" line="68"/>
      <source>Edit LuxRender project</source>
      <translation>تحرير مشروع LuxRender</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="99"/>
      <source>LuxRender template</source>
      <translation>قالب LuxRender</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="99"/>
      <source>Select a LuxRender template</source>
      <translation>حدد قالب LuxRender</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::ViewProviderPovray</name>
    <message>
      <location filename="../../ViewProvider.cpp" line="147"/>
      <source>Edit Povray project</source>
      <translation>تحرير المشروع Povray</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="178"/>
      <source>Povray template</source>
      <translation>قالب Povray</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="178"/>
      <source>Select a Povray template</source>
      <translation>حدد قالب Povray</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Raytracing</translation>
    </message>
  </context>
</TS>
